<?php

use Carbon\Carbon;
use Engelsystem\Database\Db;
use Engelsystem\Events\Listener\OAuth2;
use Engelsystem\Models\OAuth;
use Engelsystem\Models\User\Contact;
use Engelsystem\Models\User\PersonalData;
use Engelsystem\Models\User\Settings;
use Engelsystem\Models\User\State;
use Engelsystem\Models\User\User;

/**
 * @return string
 */
function register_title()
{
    return __('Register');
}

/**
 * Engel registrieren
 *
 * @return string
 */
function guest_register()
{
    $authUser = auth()->user();
    $tshirt_sizes = config('tshirt_sizes');
    $enable_tshirt_size = config('enable_tshirt_size');
    $enable_dect = config('enable_dect');
    $enable_planned_arrival = config('enable_planned_arrival');
    $min_password_length = config('min_password_length');
    $enable_password = config('enable_password');
    $enable_pronoun = config('enable_pronoun');
    $enable_angeltype_signup = config('enable_angeltype_signup');
    $config = config();
    $request = request();
    $session = session();
    $is_oauth = $session->has('oauth2_connect_provider');

    $msg = '';
    $lastName = '';
    $preName = '';
    $dect = '';
    $mobile = '';
    $pronoun = '';
    $mobile_consent = false;
    $tshirt_size = '';
    $password_hash = '';
    $selected_angel_types = [];
    $planned_arrival_date = null;

    $angel_types_source = AngelTypes();
    $angel_types = [];
    if (!empty($session->get('oauth2_groups'))) {
        /** @var OAuth2 $oauth */
        $oauth = app()->get(OAuth2::class);
        $ssoTeams = $oauth->getSsoTeams($session->get('oauth2_connect_provider'));
        foreach ($ssoTeams as $name => $team) {
            if (in_array($name, $session->get('oauth2_groups'))) {
                $selected_angel_types[] = $team['id'];
            }
        }
    }
    foreach ($angel_types_source as $angel_type) {
        $angel_types[$angel_type['id']] = $angel_type['name']
            . ($angel_type['restricted'] ? ' (' . __('Requires introduction') . ')' : '');
        if (!$angel_type['restricted']) {
            $selected_angel_types[] = $angel_type['id'];
        }
    }

    $oauth_enable_password = $session->get('oauth2_enable_password');
    if (!is_null($oauth_enable_password)) {
        $enable_password = $oauth_enable_password;
    }

    if (
        !auth()->can('register') // No registration permission
        // Not authenticated and
        || (!$authUser && !config('registration_enabled') && !$session->get('oauth2_allow_registration')) // Registration disabled
        || (!$authUser && !$enable_password && !$is_oauth) // Password disabled and not oauth
    ) {
        error(__('Registration is disabled.'));

        return page_with_title(register_title(), [
            msg(),
        ]);
    }

    if ($request->hasPostData('submit')) {
        $valid = true;

        if (!$request->has('prename') || empty($preName = strip_request_item('prename'))) {
            $valid = false;
            $msg .= error(__('Please enter your first name.'), true);
        }

        if (!$request->has('lastname') || empty($lastName = strip_request_item('lastname'))) {
            $valid = false;
            $msg .= error(__('Please enter your last name.'), true);
        }

        if (!$request->has('mobile') || empty($mobile = strip_request_item('mobile'))) {
            $valid = false;
            $msg .= error(__('Please enter your mobile number.'), true);
        } else if (User::whereName($mobile)->count() > 0) {
            $valid = false;
            $msg .= error(__('This mobile number is already in use.'), true);
        }

        if ($request->has('mobile_consent')) {
            $mobile_consent = true;
        } else {
            $valid = false;
            $msg .= error(__('Please consent to receiving notifications via SMS.'), true);
        }

        if ($enable_tshirt_size) {
            if ($request->has('tshirt_size') && isset($tshirt_sizes[$request->input('tshirt_size')])) {
                $tshirt_size = $request->input('tshirt_size');
            } else {
                $valid = false;
                $msg .= error(__('Please select your shirt size.'), true);
            }
        }

        if ($enable_password && $request->has('password') && strlen($request->postData('password')) >= $min_password_length) {
            if ($request->postData('password') != $request->postData('password2')) {
                $valid = false;
                $msg .= error(__('Your passwords don\'t match.'), true);
            }
        } else if ($enable_password) {
            $valid = false;
            $msg .= error(sprintf(
                __('Your password is too short (please use at least %s characters).'),
                $min_password_length
            ), true);
        }

        if ($request->has('planned_arrival_date') && $enable_planned_arrival) {
            $tmp = parse_date('Y-m-d H:i', $request->input('planned_arrival_date') . ' 00:00');
            $result = User_validate_planned_arrival_date($tmp);
            $planned_arrival_date = $result->getValue();
            if (!$result->isValid()) {
                $valid = false;
                error(__('Please enter your planned date of arrival. It should be after the buildup start date and before teardown end date.'));
            }
        } elseif ($enable_planned_arrival) {
            $valid = false;
            error(__('Please enter your planned date of arrival. It should be after the buildup start date and before teardown end date.'));
        }

        $selected_angel_types = [];
        foreach (array_keys($angel_types) as $angel_type_id) {
            if ($request->has('angel_types_' . $angel_type_id)) {
                $selected_angel_types[] = $angel_type_id;
            }
        }

        // Trivia
        if ($enable_pronoun && $request->has('pronoun')) {
            $pronoun = strip_request_item('pronoun');
        }
        if ($enable_dect && $request->has('dect')) {
            if (strlen(strip_request_item('dect')) <= 40) {
                $dect = strip_request_item('dect');
            } else {
                $valid = false;
                error(__('For dect numbers are only 40 digits allowed.'));
            }
        }

        if ($valid) {
            $user = new User([
                'name'          => $mobile,
                'password'      => $password_hash,
                'email'         => $mobile,
                'api_key'       => '',
                'last_login_at' => null,
            ]);
            $user->save();

            $contact = new Contact([
                'dect'   => $dect,
                'mobile' => $mobile,
            ]);
            $contact->user()
                ->associate($user)
                ->save();

            $personalData = new PersonalData([
                'first_name'           => $preName,
                'last_name'            => $lastName,
                'pronoun'              => $pronoun,
                'shirt_size'           => $tshirt_size,
                'planned_arrival_date' => $enable_planned_arrival ? Carbon::createFromTimestamp($planned_arrival_date) : null,
            ]);
            $personalData->user()
                ->associate($user)
                ->save();

            $settings = new Settings([
                'language'        => $session->get('locale'),
                'theme'           => config('theme'),
                'email_human'     => $mobile_consent,
                'email_goody'     => $mobile_consent,
                'email_shiftinfo' => $mobile_consent,
                'email_news'      => $mobile_consent,
            ]);
            $settings->user()
                ->associate($user)
                ->save();

            $state = new State([]);
            if (config('autoarrive')) {
                $state->arrived = true;
                $state->arrival_date = new Carbon();
            }
            $state->user()
                ->associate($user)
                ->save();

            if ($session->has('oauth2_connect_provider') && $session->has('oauth2_user_id')) {
                $oauth = new OAuth([
                    'provider'      => $session->get('oauth2_connect_provider'),
                    'identifier'    => $session->get('oauth2_user_id'),
                    'access_token'  => $session->get('oauth2_access_token'),
                    'refresh_token' => $session->get('oauth2_refresh_token'),
                    'expires_at'    => $session->get('oauth2_expires_at'),
                ]);
                $oauth->user()
                    ->associate($user)
                    ->save();

                $session->remove('oauth2_connect_provider');
                $session->remove('oauth2_user_id');
                $session->remove('oauth2_access_token');
                $session->remove('oauth2_refresh_token');
                $session->remove('oauth2_expires_at');
            }

            // Assign user-group and set password
            DB::insert('INSERT INTO `UserGroups` (`uid`, `group_id`) VALUES (?, -20)', [$user->id]);
            if ($enable_password) {
                auth()->setPassword($user, $request->postData('password'));
            }

            // Assign angel-types
            $user_angel_types_info = [];
            foreach ($selected_angel_types as $selected_angel_type_id) {
                DB::insert(
                    'INSERT INTO `UserAngelTypes` (`user_id`, `angeltype_id`, `supporter`) VALUES (?, ?, FALSE)',
                    [$user->id, $selected_angel_type_id]
                );
                $user_angel_types_info[] = $angel_types[$selected_angel_type_id];
            }

            engelsystem_log(
                'User ' . User_Nick_render($user, true)
                . ' signed up as: ' . join(', ', $user_angel_types_info)
            );
            success(__('Angel registration successful!'));

            // User is already logged in - that means a supporter has registered an angel. Return to register page.
            if ($authUser) {
                throw_redirect(page_link_to('register'));
            }

            // If a welcome message is present, display it on the next page
            if ($message = $config->get('welcome_msg')) {
                info((new Parsedown())->text($message));
            }

            // Login the user
            if ($user->oauth->count()) {
                /** @var OAuth $provider */
                $provider = $user->oauth->first();
                throw_redirect(url('/oauth/' . $provider->provider));
            }

            throw_redirect(page_link_to('/'));
        }
    }

    $buildup_start_date = time();
    $teardown_end_date = null;
    if ($buildup = $config->get('buildup_start')) {
        /** @var Carbon $buildup */
        $buildup_start_date = $buildup->getTimestamp();
    }

    if ($teardown = $config->get('teardown_end')) {
        /** @var Carbon $teardown */
        $teardown_end_date = $teardown->getTimestamp();
    }

    $form_data = $session->get('form_data');
    $session->remove('form_data');
    if (!$preName && !empty($form_data['first_name'])) {
        $preName = $form_data['first_name'];
    }

    if (!$lastName && !empty($form_data['last_name'])) {
        $lastName = $form_data['last_name'];
    }

    if (!$mobile && !empty($form_data['phone_number'])) {
        $mobile = $form_data['phone_number'];
    }

    return page_with_title(register_title(), [
        form_element('', __('By completing this form you\'re registering as a Chaos-Angel. This script will create you an account in the angel task scheduler.')),
        form_element('', entry_required() . ' = ' . __('Entry required!')),
        $msg,
        msg(),
        form([
            div('row', [
                div('col', [
                    form_text('prename', __('First name') . ' ' . entry_required(), $preName, false, 64, 'given-name')
                ]),
                div('col', [
                    form_text('lastname', __('Last name') . ' ' . entry_required(), $lastName, false, 64, 'family-name')
                ]),
                $enable_pronoun ? div('col', [
                    form_text('pronoun', __('Pronoun'), $pronoun, false, 15)
                ]) : '',
            ]),

            div('row', [
                div('col', [
                    form_text(
                        'mobile',
                        __('Mobile') . ' ' . entry_required(),
                        $mobile,
                        false,
                        40,
                        'tel-national'
                    ),
                    form_checkbox(
                        'mobile_consent',
                        __('I consent to receive notifications via SMS.') . ' ' . entry_required(),
                        $mobile_consent
                    ),
                ]),

                $enable_dect ? div('col', [
                    form_text('dect', __('DECT'), $dect, false, 40, 'tel-local')
                ]) : '',
            ]),

            $enable_password || $enable_planned_arrival ? div('row', [
                $enable_password ? div('col', [
                    form_password('password', __('Password') . ' ' . entry_required()),
                    form_element('', '<span class="help-block">' . icon('info-circle') . sprintf(__('Please use at least %s characters.'), $min_password_length) . '</span>'),
                ]) : '',

                $enable_planned_arrival ? div('col', [
                    form_date(
                        'planned_arrival_date',
                        __('Planned date of arrival') . ' ' . entry_required(),
                        $planned_arrival_date, $buildup_start_date, $teardown_end_date
                    )
                ]) : '',
            ]) : '',

            $enable_password || $enable_tshirt_size ? div('row', [
                $enable_password ? div('col', [
                    form_password('password2', __('Confirm password') . ' ' . entry_required())
                ]) : '',

                $enable_tshirt_size ? div('col', [
                    form_select('tshirt_size',
                        __('Shirt size') . ' ' . entry_required(),
                        $tshirt_sizes, $tshirt_size, __('Please select...')
                    )
                ]) : '',
            ]) : '',

            $enable_angeltype_signup ? div('row', [
                div('col', [
                    form_checkboxes(
                        'angel_types',
                        __('What do you want to do?') . sprintf(
                            ' (<a href="%s">%s</a>)',
                            page_link_to('angeltypes', ['action' => 'about']),
                            __('Description of job types')
                        ),
                        $angel_types,
                        $selected_angel_types
                    ),
                    form_info(
                        '',
                        __('Some angel types have to be confirmed later by a supporter at an introduction meeting. You can change your selection in the options section.')
                    )
                ])
            ]) : '',

            form_submit('submit', __('Register'))
        ])
    ]);
}

/**
 * @return string
 */
function entry_required()
{
    return icon('exclamation-triangle', 'text-info');
}
